summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAmin Bandali <bandali@gnu.org>2019-08-09 10:54:30 -0400
committerAmin Bandali <bandali@gnu.org>2019-08-09 10:54:30 -0400
commit51223843ed3a3f43fee0518af891cddb00d62696 (patch)
tree5434aca81f1b9fe19ddfd95640d044a19c7c7ae2
parent581fa9c70ad2df00f7b85527b889eebd6e4b7f6d (diff)
downloadconfigs-51223843ed3a3f43fee0518af891cddb00d62696.tar.gz
configs-51223843ed3a3f43fee0518af891cddb00d62696.tar.xz
configs-51223843ed3a3f43fee0518af891cddb00d62696.zip
guix: use cons* instead of append∘list, add slim-service-type
Diffstat (limited to '')
-rw-r--r--.config/guix/system/chaman.scm87
1 files changed, 50 insertions, 37 deletions
diff --git a/.config/guix/system/chaman.scm b/.config/guix/system/chaman.scm
index 5313d1d..53ec86d 100644
--- a/.config/guix/system/chaman.scm
+++ b/.config/guix/system/chaman.scm
@@ -1,4 +1,6 @@
-(use-modules (gnu) (gnu packages linux))
+(use-modules (gnu)
+ (gnu packages linux)
+ (srfi srfi-1)) ;for 'remove'
(use-service-modules admin desktop mail networking pm ssh xorg)
(operating-system
@@ -37,40 +39,51 @@
(list (specification->package "nss-certs"))
%base-packages))
(services
- (append
- (list (service xfce-desktop-service-type)
- (service openssh-service-type)
- (set-xorg-configuration
- (xorg-configuration
- (keyboard-layout keyboard-layout)))
- (dovecot-service #:config
- (dovecot-configuration
- ;; (log-path "/dev/stderr")
- (protocols (list (protocol-configuration
- (name "imap"))))
- (ssl? "no")
- (listen '("127.0.0.1"))
- (disable-plaintext-auth? #f)
- (auth-mechanisms '("plain"))
- (postmaster-address "bandali@gnu.local")
- (mail-location "maildir:/home/bandali/mail/%d/%n/mail")
- (userdbs (list (userdb-configuration
- (driver "static")
- (args (list "uid=bandali" "gid=users" "home=/home/bandali/mail/%d/%n")))))
- (passdbs (list (passdb-configuration
- (driver "passwd-file")
- (args (list "/home/bandali/.config/dovecot/passwd")))))))
- (service rottlog-service-type
- (rottlog-configuration))
- (service thermald-service-type)
- (service tlp-service-type
- (tlp-configuration
- (cpu-boost-on-ac? #t)
- (sound-power-save-on-bat 0)
- (sound-power-save-controller? #f)
- ;; (usb-blacklist "0e8f:00a8") ;for some reason doesn't seem to work
- (usb-autosuspend? #f)))
- (simple-service 'my-powertop-auto-tune activation-service-type
- #~(zero? (system* #$(file-append powertop "/sbin/powertop")
- "--auto-tune"))))
+ (cons*
+ (service xfce-desktop-service-type)
+ (service openssh-service-type)
+ (set-xorg-configuration
+ (xorg-configuration
+ (keyboard-layout keyboard-layout)))
+ (dovecot-service #:config
+ (dovecot-configuration
+ ;; (log-path "/dev/stderr")
+ (protocols (list (protocol-configuration
+ (name "imap"))))
+ (ssl? "no")
+ (listen '("127.0.0.1"))
+ (disable-plaintext-auth? #f)
+ (auth-mechanisms '("plain"))
+ (postmaster-address "bandali@gnu.local")
+ (mail-location "maildir:/home/bandali/mail/%d/%n/mail")
+ (userdbs (list (userdb-configuration
+ (driver "static")
+ (args (list "uid=bandali" "gid=users" "home=/home/bandali/mail/%d/%n")))))
+ (passdbs (list (passdb-configuration
+ (driver "passwd-file")
+ (args (list "/home/bandali/.config/dovecot/passwd")))))))
+ (service rottlog-service-type
+ (rottlog-configuration))
+ (service thermald-service-type)
+ (service tlp-service-type
+ (tlp-configuration
+ (cpu-boost-on-ac? #t)
+ (sound-power-save-on-bat 0)
+ (sound-power-save-controller? #f)
+ ;; (usb-blacklist "0e8f:00a8") ;for some reason doesn't seem to work
+ (usb-autosuspend? #f)))
+ (simple-service 'my-powertop-auto-tune activation-service-type
+ #~(zero? (system* #$(file-append powertop "/sbin/powertop")
+ "--auto-tune")))
+ ;; (service slim-service-type
+ ;; (slim-configuration
+ ;; (display ":0")
+ ;; (vt "vt7")))
+ ;; (service slim-service-type
+ ;; (slim-configuration
+ ;; (display ":1")
+ ;; (vt "vt8")))
+ ;; (remove (lambda (service)
+ ;; (eq? (service-kind service) gdm-service-type))
+ ;; %desktop-services)
%desktop-services)))